# AMPLIFAI

## **Overview**

This package allows to extract information from unstructured data and turns this extracted information into structured data.

## **Features**

* Creates LLM powered extraction and structuration logic
* Integrates LLM providers easily
* Provides a simple API to extract and structure data

## **Requirements**

Requires python > 3.10 and relies on langchain and pydantic
See the requirements file for more details

## **Installation**

You can install the package via pip by running the following command:

```bash
pip install amplifai
```

Alternatively, you can use any of the numerous python package managers such as poetry and uv.

## **Usage**

